@@ -147,6 +147,7 @@ HWND CDasherWindow::Create()
 
   m_pEdit = new CEdit();
   m_pEdit->Create(hWnd, m_pAppSettings->GetBoolParameter(APP_BP_TIME_STAMP));
+  m_pEdit->SetFont(m_pAppSettings->GetStringParameter(APP_SP_EDIT_FONT), m_pAppSettings->GetLongParameter(APP_LP_EDIT_FONT_SIZE));
 
 #ifdef PJC_EXPERIMENTAL
   g_hWnd = m_pEdit->GetHwnd();
@@ -154,9 +155,6 @@ HWND CDasherWindow::Create()
 
   m_pToolbar = new CToolbar(hWnd, m_pDasher);
 
-  // Set an object to handle edit events
-  m_pDasher->SetEdit(m_pEdit);
-
   // FIXME - the edit box really shouldn't need access to the interface, 
   // but at the moment it does, for training, blanking the display etc
 
@@ -304,15 +302,26 @@ bool CDasherWindow::LoadWindowState() {
 
 void CDasherWindow::HandleParameterChange(int iParameter) {
   switch(iParameter) {
-    case APP_BP_SHOW_TOOLBAR:
-      m_pToolbar->ShowToolbar(m_pAppSettings->GetBoolParameter(APP_BP_SHOW_TOOLBAR));
-      break;
-    case APP_BP_TIME_STAMP:
-      m_pEdit->TimeStampNewFiles(m_pAppSettings->GetBoolParameter(APP_BP_TIME_STAMP));
-      break;
-	case LP_MAX_BITRATE:
+   case APP_BP_SHOW_TOOLBAR:
+    m_pToolbar->ShowToolbar(m_pAppSettings->GetBoolParameter(APP_BP_SHOW_TOOLBAR));
+    break;
+   case APP_BP_TIME_STAMP:
+    m_pEdit->TimeStampNewFiles(m_pAppSettings->GetBoolParameter(APP_BP_TIME_STAMP));
+    break;
+	 case LP_MAX_BITRATE:
 	  m_pSlidebar->SetValue(m_pAppSettings->GetLongParameter(LP_MAX_BITRATE) / 100.0);
 	  break;
+   case BP_DASHER_PAUSED:
+    if(m_pAppSettings && m_pDasher && 
+       m_pAppSettings->GetBoolParameter(BP_DASHER_PAUSED) && 
+       m_pAppSettings->GetBoolParameter(APP_BP_COPY_ALL_ON_STOP))
+      if(m_pEdit)
+        m_pEdit->CopyAll();
+    break;
+   case APP_SP_EDIT_FONT:
+   case APP_LP_EDIT_FONT_SIZE:
+     m_pEdit->SetFont(m_pAppSettings->GetStringParameter(APP_SP_EDIT_FONT),m_pAppSettings->GetLongParameter(APP_LP_EDIT_FONT_SIZE));
+     break;
   }
 }
 
@@ -456,6 +465,7 @@ LRESULT CDasherWindow::OnCommand(UINT message, WPARAM wParam, LPARAM lParam, BOO
 		  string FontName;
 		  WinUTF8::wstring_to_UTF8string(lf.lfFaceName, FontName);
 		  m_pAppSettings->SetStringParameter(APP_SP_EDIT_FONT, FontName);
+      m_pAppSettings->SetLongParameter(APP_LP_EDIT_FONT_SIZE, lf.lfHeight);
 							   }
 							   break;
 	  case ID_OPTIONS_DASHERFONT:
@@ -509,7 +519,8 @@ LRESULT CDasherWindow::OnCommand(UINT message, WPARAM wParam, LPARAM lParam, BOO
 		  return 0;
 	  case IDM_EXIT:
 		  //SendMessage(m_hWnd, WM_CLOSE, 0, 0);
-		  DestroyWindow();
+		  if(m_pEdit->QueryClose())
+        DestroyWindow();
 		  return 0;
 	
 		  // FIXME - These options shouldn't pass through the interface
@@ -651,8 +662,12 @@ LRESULT CDasherWindow::OnDasherEvent(UINT message, WPARAM wParam, LPARAM lParam,
         HandleParameterChange(((CParameterNotificationEvent *)pEvent)->m_iParameter);
         break;
       case EV_EDIT:
+        if(m_pEdit) 
+          m_pEdit->HandleEvent(pEvent);
         break;
       case EV_EDIT_CONTEXT:
+        if(m_pEdit && m_pDasher)
+          m_pDasher->SetContext(m_pEdit->GetContext(((CEditContextEvent*)pEvent)->m_iMaxLength));
         break;
       case EV_START:
         break;
@@ -684,7 +699,8 @@ LRESULT CDasherWindow::OnDestroy(UINT message, WPARAM wParam, LPARAM lParam, BOO
 {
 	bHandled = TRUE;
 	OutputDebugString(TEXT("DasherWindow WM_DESTROY\n"));
-
+  //if(m_pEdit)
+	 // m_pEdit->New();
 	if(m_pEdit != 0) {
 		m_pEdit->write_to_file();
 	}
@@ -719,9 +735,12 @@ LRESULT CDasherWindow::OnInitMenuPopup(UINT message, WPARAM wParam, LPARAM lPara
 
 LRESULT CDasherWindow::OnClose(UINT message, WPARAM wParam, LPARAM lParam, BOOL& bHandled)
 {
-	bHandled = FALSE;
-	SaveWindowState();
-	return 0;
+	bHandled = TRUE;
+  if(m_pEdit->QueryClose()) {
+	  SaveWindowState();
+    DestroyWindow();
+  }
+  return 0;
 }
 
 LRESULT CDasherWindow::OnSize(UINT message, WPARAM wParam, LPARAM lParam, BOOL& bHandled)
